from __future__ import generators
import plus
import AI
from AI import vector3
import Arenas
import Gooey
import math
import Tactics

class LilFlipper(AI.SuperAI):
    "AI for flippers that will only fire the weapon when the bot is not inverted."
    name = "LilFlipper"
    # This AI will only fire its weapon when the bot is not inverted, but will still fire at an inverted opponent.  If you're AIing an invertible bot that is to use its weapon both ways up, don't use this.
    # Name the button to fire the weapon "Flip", the button for the srimech "Srimech" and the weapon smartzone "flip".
    # If the weapon firing button is anything other than "Flip", put 'triggers':["Button name"] in the bindings for the bot.
    # By default, this AI will attempt to self-right once every second.  To change this, put 'SrimechInterval':[number of seconds] in the bindings for the bot.
    # Edit of Chopper.py made by Lilleh__

    def __init__(self, **args):
        AI.SuperAI.__init__(self, **args)
               
        self.zone = "flip"
        self.triggers = ["Flip"]
        self.triggers2 = ["Srimech"]
        self.sritime = 8
        
        if 'triggers' in args: self.triggers = args['triggers']
        if 'SrimechInterval' in args: self.sritime = args['SrimechInterval'] * 8
        
        self.tactics.append(Tactics.Engage(self))
        
    def Activate(self, active):
        if active:
            if AI.SuperAI.debugging:
                self.debug = Gooey.Plain("watch", 0, 75, 100, 75)
                tbox = self.debug.addText("line0", 0, 0, 100, 15)
                tbox.setText("Throttle")
                tbox = self.debug.addText("line1", 0, 15, 100, 15)
                tbox.setText("Turning")
                tbox = self.debug.addText("line2", 0, 30, 100, 15)
                tbox.setText("")
                tbox = self.debug.addText("line3", 0, 45, 100, 15)
                tbox.setText("")
            
            self.RegisterSmartZone(self.zone, 1)
            
        return AI.SuperAI.Activate(self, active)

    def Tick(self):
        # fire weapon
        if self.weapons:
            targets = [x for x in self.sensors.itervalues() if x.contacts > 0 \
                and not plus.isDefeated(x.robot)]
            if len(targets) > 0 and not self.IsUpsideDown():
                for trigger in self.triggers: self.Input(trigger, 0, 1)
            
        return AI.SuperAI.Tick(self)

    def InvertHandler(self):
        # fire weapon once per second (until we're upright!)
        while 1:
            for trigger in self.triggers2: self.Input(trigger, 0, 1)
            
            for i in range(0, self.sritime):
                yield 0

    def LostComponent(self, id):
        # if we lose all our weapons, stop using the Engage tactic and switch to Shove
        if id in self.weapons: self.weapons.remove(id)
        
        if not self.weapons:
            self.RemoveTactic("Engage")
                
            self.tactics.append(Tactics.Shove(self))
            self.tactics.append(Tactics.Charge(self))
            
        return AI.SuperAI.LostComponent(self, id)
        
    def DebugString(self, id, string):
        if self.debug:
            if id == 0: self.debug.get("line0").setText(string)
            elif id == 1: self.debug.get("line1").setText(string)
            elif id == 2: self.debug.get("line2").setText(string)
            elif id == 3: self.debug.get("line3").setText(string)
    
AI.register(LilFlipper)
