from __future__ import generators
import plus
import AI
from AI import vector3
import Arenas
import Gooey
import math
import Tactics
from Omni import Omni

class LilMultiWeapon(Omni):
    "Adds four extra burst weapon slots to Omni.py that will stop firing after certain parts are broken off"
    name = "LilMultiWeapon"
    # Has most of the functionality of Omni.py (set a tactic in bindings, button called Spin for spinning weapon, button called Srimech for srimech, button called Fire w/ smartzone called weapon for burst weapon)
    # Adds four extra burst weapon slots.  Buttons are Fire1, Fire2, Fire3 and Fire4, smartzones are weapon1, weapon2, weapon3 and weapon4.
    # Use 'weapons' in bindings to set which parts Fire1 should stop being fired after, 'sweapons' for Fire2, 'tweapons' for Fire3 and 'qweapons' for Fire4.
    # Tactic change won't happen until all of weapons, sweapons, tweapons and qweapons have been broken off.
    # sweapons, tweapons and qweapons default to the same component ids as weapons if not stated in bindings.
    # Edited from OmniMultiZone.py by Lilleh__.
    def __init__(self, **args):
        Omni.__init__(self, **args)
        
        self.sweapons = self.weapons
        self.tweapons = self.weapons
        self.qweapons = self.weapons
        
        if 'sweapons' in args: self.sweapons = list(args['sweapons'])
        if 'tweapons' in args: self.tweapons = list(args['tweapons'])
        if 'qweapons' in args: self.qweapons = list(args['qweapons'])

    def Activate(self, active):
        bReturn = Omni.Activate(self, active)
        if active:
            self.RegisterSmartZone("weapon1", 2)
            self.RegisterSmartZone("weapon2", 3)
            self.RegisterSmartZone("weapon3", 4)
            self.RegisterSmartZone("weapon4", 5)

        return bReturn

    def LostComponent(self, id):
        # if we lose all our weapons, stop using the Engage tactic and switch to Shove
        if id in self.weapons: self.weapons.remove(id)
        if id in self.sweapons: self.sweapons.remove(id)
        if id in self.tweapons: self.tweapons.remove(id)
        if id in self.qweapons: self.qweapons.remove(id)
        
        if not self.weapons and not self.sweapons and not self.tweapons and not self.qweapons:
            self.RemoveTactic("Engage")
                
            self.tactics.append(Tactics.Shove(self))
            self.tactics.append(Tactics.Charge(self))
            
        return AI.SuperAI.LostComponent(self, id)

    def SmartZoneEvent(self, direction, id, robot, chassis):
        if id == 1:
            if direction == 1:
                AI.SuperAI.SmartZoneEvent(self, direction, id, robot, chassis)
        elif id == 2:
            if robot > 0:
                if direction == 1 and self.weapons:
                    self.Input("Fire1", 0, 1)
                if direction == -1 or not self.weapons:
                    self.Input("Fire1", 0, 0)
        elif id == 3:
            if robot > 0:
                if direction == 1 and self.sweapons:
                    self.Input("Fire2", 0, 1)
                if direction == -1 or not self.sweapons:
                    self.Input("Fire2", 0, 0)
        elif id == 4:
            if robot > 0:
                if direction == 1 and self.tweapons:
                    self.Input("Fire3", 0, 1)
                if direction == -1 or not self.tweapons:
                    self.Input("Fire3", 0, 0)
        elif id == 5:
            if robot > 0:
                if direction == 1 and self.qweapons:
                    self.Input("Fire4", 0, 1)
                if direction == -1 or not self.qweapons:
                    self.Input("Fire4", 0 ,0)

        return True

AI.register(LilMultiWeapon)